@@ -1,13 +1,14 @@
-# coding: utf-8
+
+from __future__ import annotations
 
 if False:  # MYPY
     from typing import Dict, Any  # NOQA
 
 _package_data = dict(
     full_package_name='ruamel.yaml',
-    version_info=(0, 18, 3),
-    __version__='0.18.3',
-    version_timestamp='2023-10-29 16:24:20',
+    version_info=(0, 18, 7),
+    __version__='0.18.7',
+    version_timestamp='2024-12-30 18:02:20',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     description='ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation of comments, seq/map flow style, and map key order',  # NOQA
@@ -19,27 +20,20 @@ _package_data = dict(
         'docs': ['ryd', 'mercurial>5.7'],
     },
     classifiers=[
-        'Programming Language :: Python :: 3 :: Only',
-        'Programming Language :: Python :: 3.7',
-        'Programming Language :: Python :: 3.8',
-        'Programming Language :: Python :: 3.9',
-        'Programming Language :: Python :: 3.10',
-        'Programming Language :: Python :: 3.11',
-        'Programming Language :: Python :: 3.12',
         'Programming Language :: Python :: Implementation :: CPython',
         'Topic :: Software Development :: Libraries :: Python Modules',
         'Topic :: Text Processing :: Markup',
         'Typing :: Typed',
     ],
     keywords='yaml 1.2 parser round-trip preserve quotes order config',
-    read_the_docs='yaml',
+    url_doc='https://yaml.dev/doc/{full_package_name}',
     supported=[(3, 7)],  # minimum
     tox=dict(
         env='*',
         fl8excl='_test/lib,branch_default',
     ),
     # universal=True,
-    python_requires='>=3',
+    python_requires='>=3.7',
 )  # type: Dict[Any, Any]
 
 
